/* -*-c-*-
 *
 * $Id: cancel.c,v 1.6 2004/04/08 01:36:14 mdw Exp $
 *
 * Handle Escape keypresses, directing them to cancel buttons
 *
 * (c) 1998 Straylight/Edgeware
 */

/*----- Licensing notice --------------------------------------------------* 
 *
 * This file is part of the mgLib GTK utilities library.
 *
 * mgLib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 * 
 * mgLib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU Library General Public
 * License along with mgLib; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 */

/*----- Header files ------------------------------------------------------*/

#include <gtk/gtk.h>
#include <gdk/gdkkeysyms.h>

#include "cancel.h"

/*----- Main code ---------------------------------------------------------*/

/* --- @cancel@ --- *
 *
 * Arguments:	@GtkWindow *win@ = window in which this is happening
 *		@GtkWidget *w@ = widget to activate, or null
 *
 * Returns:	---
 *
 * Use:		Sets up @win@ so that a press of `escape' will activate
 *		@w@ or destroy @win@.
 */

static gboolean cancel_press(GtkWidget *w, GdkEventKey *ev, gpointer *p)
{
  if (ev->keyval == GDK_Escape) {
    if (p)
      gtk_widget_activate(GTK_WIDGET(p));
    else
      gtk_object_destroy(GTK_OBJECT(w));
    return (1);
  }
  return (0);
}

void cancel(GtkWindow *win, GtkWidget *w)
{
  gtk_signal_connect(GTK_OBJECT(win), "key_press_event",
		     GTK_SIGNAL_FUNC(cancel_press), w);
}

/*----- That's all, folks -------------------------------------------------*/
